============================================================
``psyclone.tests.psyir.backend.fortran_unknown_declns_test``
============================================================

.. automodule:: psyclone.tests.psyir.backend.fortran_unknown_declns_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.psyir.backend.fortran_unknown_declns_test
